@@ -11,19 +11,23 @@ from .exceptions import LeidenPlusSyntaxError
 
 class DivisionsPreproc(Preprocessor):
 
-    RE_OPEN = re.compile(r"""
+    RE_OPEN = re.compile(
+        r"""
         (?:
-          <D=\.(\w+)(?:\.(\w+))?          # Division mark <D=.number(.divisontype)? ... =D>
-          |(<=)(?!\.(?:ms|lb|cb|pb|gb))   # Paragraph mark <= ... => (Check if it is not a milestone)
+          <D=\.(\w+)(?:\.(\w+))?         # Division mark
+                                         # <D=.number(.divisontype)? ... =D>
+          |(<=)(?!\.(?:ms|lb|cb|pb|gb))  # Paragraph mark <= ... =>
+                                         # (Check if it is not a milestone)
         )\s*""",
-        flags = re.VERBOSE
+        flags=re.VERBOSE
     )
-    RE_CLOSE = re.compile(r"""
+    RE_CLOSE = re.compile(
+        r"""
         (?:
-          (=D>)                                             # Division mark end
-          |(?<!<=\.(?:ms|lb|cb|pb|gb) (?:[^<\n]+?)\s*)=>    # Paragraph mark end
+          (=D>)                                            # Division mark end
+          |(?<!<=\.(?:ms|lb|cb|pb|gb) (?:[^<\n]+?)\s*)=>   # Paragraph mark end
         )\s*""",
-        flags = re.VERBOSE
+        flags=re.VERBOSE
     )
 
     def _find_first_mark(self, line):
@@ -35,10 +39,10 @@ class DivisionsPreproc(Preprocessor):
             return close_match, 'c'
         elif open_match and (not close_match):
             return open_match, 'o'
-        else: # open_match and close_match
+        else:  # open_match and close_match
             if open_match.start() < close_match.start():
                 return open_match, 'o'
-            else: # open_match.start() > close_match.start()
+            else:  # open_match.start() > close_match.start()
                 return close_match, 'c'
 
     def run(self, lines):
@@ -53,13 +57,18 @@ class DivisionsPreproc(Preprocessor):
                 new_lines.append(line[:match.start()])
                 if mark_type == 'o':
                     if in_ab:
-                        raise LeidenPlusSyntaxError('<= ... => cannot be nested')
+                        raise LeidenPlusSyntaxError(
+                            '<= ... => cannot be nested'
+                        )
                     n, div_type, ab = match.groups()
                     if ab:
                         in_ab = True
                         new_line = f'{{AB-OPEN id={div_counter}}}'
                     elif div_type:
-                        new_line = f'{{DIV-OPEN id={div_counter} subtype={div_type} n={n}}}'
+                        new_line = (
+                            f'{{DIV-OPEN id={div_counter} '
+                            f'subtype={div_type} n={n}}}'
+                        )
                     else:
                         new_line = f'{{DIV-OPEN id={div_counter} n={n}}}'
                     new_lines += ['', new_line, '']
@@ -68,13 +77,26 @@ class DivisionsPreproc(Preprocessor):
                 elif mark_type == 'c':
                     div = match.group(1)
                     if div and in_ab:
-                        raise LeidenPlusSyntaxError('Incorrect division syntax: <= ... =D>')
+                        raise LeidenPlusSyntaxError(
+                            'Incorrect division syntax: <= ... =D>'
+                        )
                     elif (not div) and (not in_ab):
-                        raise LeidenPlusSyntaxError('Incorrect division syntax: <D= ... =>')
+                        raise LeidenPlusSyntaxError(
+                            'Incorrect division syntax: <D= ... =>'
+                        )
                     try:
-                        new_lines += ['', f'{{{"DIV" if div else "AB"}-CLOSE id={div_ids[-1]}}}', '']
+                        new_lines += [
+                            '',
+                            (
+                                f'{{{"DIV" if div else "AB"}-CLOSE '
+                                f'id={div_ids[-1]}}}'
+                            ),
+                            ''
+                        ]
                     except IndexError:
-                        raise LeidenPlusSyntaxError(f'Text has a ={"D" if div else ""}> too many')
+                        raise LeidenPlusSyntaxError(
+                            f'Text has a ={"D" if div else ""}> too many'
+                        )
                     else:
                         del div_ids[-1]
                         if not div:
@@ -84,7 +106,8 @@ class DivisionsPreproc(Preprocessor):
             new_lines.append(line)
         if div_ids != []:
             raise LeidenPlusSyntaxError(
-                "Text ended while some Leiden+ division marks have not been closed"
+                "Text ended while some Leiden+ division marks have not been "
+                "closed"
             )
         return new_lines
 
@@ -95,21 +118,31 @@ class DivisionMarkProcessor(BlockProcessor):
     RE_CLOSE = re.compile(r'^\{(DIV-CLOSE|AB-CLOSE) (.+?)\}')
 
     def test(self, parent, block):
-        return bool(self.RE_OPEN.search(block)) or bool(self.RE_CLOSE.search(block))
+        return (
+            bool(self.RE_OPEN.search(block))
+            or bool(self.RE_CLOSE.search(block))
+        )
 
     def run(self, parent, blocks):
         lines = blocks.pop(0).split('\n')
-        if len(lines) > 1 and not all(re.search(r'\s*', line) for line in lines[1:]):
+        if (
+            len(lines) > 1 and
+            not all(re.search(r'\s*', line) for line in lines[1:])
+        ):
             blocks.insert(0, '\n'.join(lines[1:]))
 
         match = self.RE_OPEN.search(lines[0])
         if match:
-            self.parser.state.set('lp-div') # TODO: this parser state allows for the divison logic to be much cleaner!
+            self.parser.state.set('lp-div')
+            # TODO: this parser state allows for the divison logic to be much
+            # cleaner!
         else:
             match = self.RE_CLOSE.search(lines[0])
             self.parser.state.reset()
         el = etree.SubElement(parent, match.group(1))
-        attribs = [attr.split('=', maxsplit=1) for attr in match.group(2).split(' ')]
+        attribs = [
+            attr.split('=', maxsplit=1) for attr in match.group(2).split(' ')
+        ]
         [el.set(*attrib) for attrib in attribs]
 
 
@@ -118,7 +151,7 @@ class DivisionMarkTreeproc(Treeprocessor):
     def run(self, root):
         for tag in ['AB', 'DIV']:
             el_close = root.find(f'./{tag}-CLOSE')
-            while el_close != None:
+            while el_close is not None:
                 ID = el_close.attrib['id']
                 el_open = root.find(f'./{tag}-OPEN[@id="{ID}"]')
                 if el_open.tail:
@@ -143,7 +176,10 @@ class ColumnContainerTreeproc(Treeprocessor):
     """ Wrap column-like divisions in a <seg type="columns"/> container """
 
     def _is(self, tag_name, el):
-        return el.tag == 'div' and el.attrib.get('type') == 'textpart' and el.attrib.get('subtype') == tag_name
+        return (
+            el.tag == 'div' and el.attrib.get('type') == 'textpart'
+            and el.attrib.get('subtype') == tag_name
+        )
 
     def insert_containers(self, root, tag_name, seg_attribs={}):
         # Select all parents of columns
@@ -155,7 +191,9 @@ class ColumnContainerTreeproc(Treeprocessor):
                     break
                 else:
                     if self._is(tag_name, el):
-                        col_container = etree.Element('seg', type='columns', **seg_attribs)
+                        col_container = etree.Element(
+                            'seg', type='columns', **seg_attribs
+                        )
                         parent.insert(i, col_container)
                         while self._is(tag_name, el):
                             col_container.append(el)
@@ -167,11 +205,14 @@ class ColumnContainerTreeproc(Treeprocessor):
 
     def run(self, root):
         self.insert_containers(root, 'column')
-        self.insert_containers(root, 'tab', seg_attribs={'rend': 'hide-labels'})
+        self.insert_containers(
+            root, 'tab', seg_attribs={'rend': 'hide-labels'}
+        )
 
 
 THROWAWAY_TAG = 'throwaway-p'
 
+
 class TrivialProcessor(BlockProcessor):
     """ Fallback alternative to the ParagraphProcessor. """
 
@@ -181,9 +222,9 @@ class TrivialProcessor(BlockProcessor):
     def run(self, parent, blocks):
         block = blocks.pop(0)
         if block.strip():
-            # In order for inlineprocessors to work, we have to wrap the content in
-            # at least one element. Therefore we create this throwaway which we filter
-            # in post-processing.
+            # In order for inlineprocessors to work, we have to wrap the
+            # content in at least one element. Therefore we create this
+            # throwaway which we filter in post-processing.
             p = etree.SubElement(parent, THROWAWAY_TAG)
             p.text = block.lstrip()
 
@@ -191,4 +232,29 @@ class TrivialProcessor(BlockProcessor):
 class RemoveThrowaway(Postprocessor):
     """ Remove throwaway that TrivialProcessor creates """
     def run(self, text):
-        return re.sub(f'\s*\<\s*/?\s*{THROWAWAY_TAG}\s*/?\s*\>\s*', '', text)
+        return re.sub(fr'\s*\<\s*/?\s*{THROWAWAY_TAG}\s*/?\s*\>\s*', '', text)
+
+
+def register_divisions(md):
+    md.preprocessors.register(
+        DivisionsPreproc(md), 'divison_preproc', 120
+    )
+    md.parser.blockprocessors.register(
+        DivisionMarkProcessor(md.parser), 'divison_marks', 119
+    )
+    md.treeprocessors.register(
+        DivisionMarkTreeproc(md), 'divison_treeproc', 120
+    )
+    md.treeprocessors.register(
+        ColumnContainerTreeproc(md), 'col_container', 119
+    )
+    md.postprocessors.register(
+        RemoveThrowaway(md), 'remove_throwaway', 1
+    )
+
+
+def deregister_paragraphs(md):
+    md.parser.blockprocessors.deregister('paragraph')
+    md.parser.blockprocessors.register(
+        TrivialProcessor(md.parser), 'fallback', 0
+    )
