@@ -6,19 +6,21 @@ from markdown.blockprocessors import BlockProcessor
 
 LINE_NUM = r'([0-9]+[a-z]?´?(?:[–\-/][0-9]*[a-z]?)?)\.(-?)'
 
+
 class LineNumsPreproc(Preprocessor):
 
     RE_LINE = re.compile(fr'^{LINE_NUM}\s*(.*?)(?<!\s)\s*$')
 
     def run(self, lines):
         new_lines = []
-        prev = True # Track whether previous line has a line number or not
-                    # so we can separate numbered lines in blocks
+        prev = True  # Track whether previous line has a line number or not
+        # so we can separate numbered lines in blocks
         for line in lines:
             match = self.RE_LINE.search(line)
             if match:
                 n, hyph, rem = match.groups()
-                n = n.replace('-','–') # Use en-dash for ranges instead of hyphen
+                n = n.replace('-', '–')
+                # Use en-dash for ranges instead of hyphen
                 line_break = ' break=no' if hyph else ''
                 if not prev:
                     new_lines.append('')
@@ -37,7 +39,9 @@ class NumberedBlocksProcessor(BlockProcessor):
     RE_LINE_DECL = re.compile(r'^\{LINE (.+?)\}')
 
     def test(self, parent, block):
-        return all(self.RE_LINE_DECL.search(line) for line in block.split('\n'))
+        return all(
+            self.RE_LINE_DECL.search(line) for line in block.split('\n')
+        )
 
     def run(self, parent, blocks):
         lines = blocks.pop(0).split('\n')
@@ -50,3 +54,12 @@ class NumberedBlocksProcessor(BlockProcessor):
             for attr in attribs:
                 line_el.set(*attr)
             line_el.text = content
+
+
+def register_line_nums(md):
+    md.preprocessors.register(
+        LineNumsPreproc(md), 'linenums_preproc', 11
+    )
+    md.parser.blockprocessors.register(
+        NumberedBlocksProcessor(md.parser), 'lineblocks', 120
+    )
